==> ml_legit-19.6.4041-py2.py3-none-any.whl: missinglink/legit/object_store/gcs/cloud_object_store.py <==
# -*- coding: utf-8 -*-
import logging
from collections import OrderedDict
from ..ml_base_object_store import _MlBaseObjectStore
from ...connection_mixin import ConnectionMixin
from ...dulwich.objects import hex_to_filename, Blob


class CloudObjectStore(ConnectionMixin, _MlBaseObjectStore):
    def __init__(self, connection):
        _MlBaseObjectStore.__init__(self)
        super(CloudObjectStore, self).__init__(connection)
        self.__volume_id = self._connection.data_volume_config.volume_id
        self.__storage_volume_id = self._connection.data_volume_config.storage_volume_id

    @classmethod
    def _get_shafile_path(cls, sha):
        # Check from object dir
        return hex_to_filename('objects', sha).replace('\\', '/')

    def _get_loose_object_data(self, object_name):
        pass

    def get_source_path(self, metadata):
        sha = metadata['@id']

        if self._connection.data_volume_config.embedded:
            object_name = '%s/%s' % (self.__storage_volume_id, self._get_shafile_path(sha))
        else:
            object_name = metadata['@url']

        return object_name

    def _get_loose_object(self, metadata):
        logging.debug('get object %s', metadata)

        sha = metadata['@id']

        object_name = self.get_source_path(metadata)

        data = self._get_loose_object_data(object_name)

        blob = Blob()
        blob.set_raw_chunks([data], sha)

        return blob

    @classmethod
    def _get_content_headers(cls, content_type=None):
        headers = OrderedDict()
        if content_type:
            headers['Content-Type'] = content_type

        return headers

==> ml_legit-19.6.4076-py2.py3-none-any.whl: missinglink/legit/object_store/gcs/cloud_object_store.py <==
# -*- coding: utf-8 -*-
import abc
import logging
from collections import OrderedDict

import six

from ..ml_base_object_store import _MlBaseObjectStore
from ...connection_mixin import ConnectionMixin
from ...dulwich.objects import hex_to_filename, Blob


@six.add_metaclass(abc.ABCMeta)
class CloudObjectStore(ConnectionMixin, _MlBaseObjectStore):
    def __init__(self, connection):
        _MlBaseObjectStore.__init__(self)
        super(CloudObjectStore, self).__init__(connection)
        self.__volume_id = self._connection.data_volume_config.volume_id
        self.__storage_volume_id = self._connection.data_volume_config.storage_volume_id

    @property
    def _storage_volume_id(self):
        return self.__storage_volume_id

    @classmethod
    def _get_shafile_path(cls, sha):
        # Check from object dir
        return hex_to_filename('objects', sha).replace('\\', '/')

    @abc.abstractmethod
    def _get_loose_object_data(self, object_name):
        """
        get the content of object_name
        :param object_name:
        :return:
        """

    def get_source_path(self, metadata):
        sha = metadata['@id']

        if self._connection.data_volume_config.embedded:
            return '%s/%s/%s' % (self._connection.data_volume_config.bucket_name, self.__storage_volume_id, self._get_shafile_path(sha))

        return metadata['@url']

    def _get_loose_object(self, metadata):
        logging.debug('get object %s', metadata)

        sha = metadata['@id']

        object_name = self.get_source_path(metadata)

        data = self._get_loose_object_data(object_name)

        blob = Blob()
        blob.set_raw_chunks([data], sha)

        return blob

    @classmethod
    def _get_content_headers(cls, content_type=None):
        headers = OrderedDict()
        if content_type:
            headers['Content-Type'] = content_type

        return headers
